@@ -1,19 +1,19 @@
 /*
  * Copyright (C) 2001,2002 Red Hat, Inc.
  *
- * This is free software; you can redistribute it and/or modify it under
- * the terms of the GNU Library General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 
@@ -557,7 +557,7 @@ main(int argc, char **argv)
 		 icon_title = FALSE, shell = TRUE, highlight_set = FALSE,
 		 cursor_set = FALSE, reverse = FALSE, use_geometry_hints = TRUE,
 		 antialias = TRUE, use_scrolled_window = FALSE,
-		 show_object_notifications = FALSE;
+		 show_object_notifications = FALSE, rewrap = TRUE;
 	char *geometry = NULL;
 	gint lines = -1;
 	const char *message = "Launching interactive shell...\r\n";
@@ -592,6 +592,11 @@ main(int argc, char **argv)
 			G_OPTION_ARG_NONE, &dingus,
 			"Highlight URLs inside the terminal", NULL
 		},
+		{
+			"no-rewrap", 'R', G_OPTION_FLAG_REVERSE,
+			G_OPTION_ARG_NONE, &rewrap,
+			"Disable rewrapping on resize", NULL
+		},
 		{
 			"shell", 'S', G_OPTION_FLAG_REVERSE,
 			G_OPTION_ARG_NONE, &shell,
@@ -923,6 +928,8 @@ main(int argc, char **argv)
 	}
 	vte_terminal_set_cursor_shape(terminal, cursor_shape);
 
+	vte_terminal_set_rewrap_on_resize(terminal, rewrap);
+
 	/* Set the default font. */
         G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
 	vte_terminal_set_font_from_string_full(terminal, font,
